@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package conn
@@ -794,6 +789,7 @@ func Test_connHandler_read(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -807,7 +803,6 @@ func Test_connHandler_read(t *testing.T) {
 			}()
 
 			ch := &connHandler{conn: client, logr: log.New("Test")}
-
 			go func() {
 				for _, m := range tt.args.message {
 					_, err := server.Write(m)
@@ -893,6 +888,7 @@ func Test_connHandler_readExpected(t *testing.T) {
 						},
 						err: nil,
 					},
+					//nolint:dupl
 					{
 						data: []byte{
 							0x60, 0x82, 0x01, 0x01, 0x6b, 0x82, 0x00, 0xfd, 0xa0, 0x23, 0x69, 0x21, 0xa0, 0x05, 0x0d,
@@ -936,6 +932,7 @@ func Test_connHandler_readExpected(t *testing.T) {
 				"1",
 				3,
 				[]readResponse{
+					//nolint:dupl
 					{
 						data: []byte{
 							0x60, 0x82, 0x01, 0x01, 0x6b, 0x82, 0x00, 0xfd, 0xa0, 0x23, 0x69, 0x21, 0xa0, 0x05, 0x0d,
@@ -1093,6 +1090,7 @@ func Test_connHandler_readExpected(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
